Juno: vinyl, DJ & studio equipment from the world s favourite music store
Description: The world s largest range of dance music vinyl, CD and downloads, with over 1,000,000 tracks available. Vinyl and CDs from the best online dance music store - Juno Records
Keywords: juno records dance music vinyl vinil vynil

Skip Navigation

Secure shopping

MP3, WAV, FLAC

Juno Download offers over 3 million dance tracks in MP3, WAV & FLAC formats, featuring genre pages, advanced audioplayer, super-fast download speeds.

Visit Juno Download

Secure shopping

Studio equipment

Our full range of studio equipment from all the leading equipment and software brands. Guaranteed fast delivery and low prices.

Visit Juno Studio

Secure shopping

DJ equipment

Our full range of DJ equipment from all the leading equipment and software brands. Guaranteed fast delivery and low prices. Visit Juno DJ

Online magazine

Features the latest dance music news, interviews, music and tech reviews, podcasts & more...

Visit Juno Plus

In:

| VIEW RELEASES new this week new today new last 8 weeks charts back cat represses DJ charts classics discounts all vinyl CD download |

| MY JUNO My artists My back-in-stock alerts My labels My account My wishlist My charts My new release e-mails My order history My coming soon alerts |

| DEPARTMENTS Coming soon Gift certificates Classics Create a chart Represses Juno images Full label list Juno Plus Top Labels Portable Juno Player |

| CONTACT US / HELP About Juno Manage account Contact Us (Customers) Ordering FAQ Ordering Problems Feedback Resubmit Card Mailing List Terms and Conditions Finance Juno Distribution |

| Follow @junorecords |

| SINGLE OF THE WEEK MAX GRAEF/GLENN ASTRO Magic Johnson Ninja Tune OYE crew and Berlin purveyors of dusty, hip-hop inspired deep house make their major label debut for Ninja Tune and good on them. It really is their time at present, what with their Money $ex and Box Aus Holz imprints going from strength to strength. "Magic Johnson" inspires the greatness of the song's namesake. All dusty Read more... |

| ALBUM OF THE WEEK VARIOUS I Have A Question trip Nina Kraviz seems to have a thing for double-pack compilations. Of the first three releases on her label, Trip, two were double-vinyl sets featuring contributions from a wide range of artists. This fourth missive from the imprint sticks to Kraviz's tried-and-tested formula. Predictably, it's stuffed with high-grade materi Read more... |

| THIS WEEK AT JUNO Damien Dubrovnik - The Light of God Shines Eternal (Jealous God) With Damien Dubrovnik’s arrival on Jealous God it’s become pretty darn official the Danish pair are not only a respected name, but now a recognised one. Although the group first explicitly appeared on Juno Plus with news of their arrival on Helm’s label Alter, the Damien Dubrovnik name has regularly snuck into other news stories and reviews, to being named-dropped by Juan Mendez (aka Silent Servant) in Richard Brophy’s interview, while in his interview with Northern Electronics artist Varg, James Manning watched Jonas Rönnberg excitedly spill a tote bag full of tapes from the duo's Posh Isolation label with over a table. So it’s with great pleasure that we watch on as Damien Dubrovnik’s profile grows with three searing sessions of theatrical and classically-based productions of powerful, but not overwhelming, cuts of industrial ambience for the always reliable Jealous God. Petre Inspirescu – Vin Ploile (Mule Musiq) One of the greatest album openers this year is “Delir 1” from Petre Inspirescu’s surprise ‘ambient’ album for Japanese label Mule Musiq. Vin Ploile is the Romanian’s third album and his first long player not granted a release on his own [a:rpia:r] - and it feels right at home on Mule. While the cheesy horns in “Pan'la Glezne” may be somewhat of a turn off, Vin Ploile makes up for it in the cheery tones and shaker percussion in “Delir 2” and watery, playfulness of “Delir 4”. There’s a large acoustic bent at play here too, with clarinets, Latin guitars and jazzy drums delivering relaxing vibes in “Delir 5” and the ambient-laden “Lumiere”, while the mournful soundscapes of “Delir 6” and “Delir7” are simply touching. Sadly Vin Ploile hasn’t received much attention this year, as it’s a wonderful album deserved of more, but if you are one of the lucky ones that can channel into this side of Inspirescu’s sound, it’s a diamond in the minimal, eastern European rough. Mike Cooper - White Shadows In The South Seas (Sacred Summits) Mike Cooper has really nailed it when it comes to blending strokes of jazz, guitar and synth noodling to ambient soundscapes of the Pacific Isles. So much so, Lindsay Todd and Stuart Leath’s consistently impressive Sacred Summits label commits this 14-track album to vinyl following its original 2013 CD release by Lawrence English’s Room40. In comparison to the fare more obscure Fratello Mare album Room40 released this year, White Shadows In The South Seas is less unsettling, with songs like “Dr Derelict” sounding like the music you’d hear in a 5 star Fijian resort, but far less tacky or imperial. It’s an album definitely deserving of the tag ‘long player’ and it combines the string steel guitar playing of someone like John Fahey with the field recordings of Chris Watson, with a little bit of drunkenness thrown in. Chevel – Blurse Remixed (Stroboscopic Artefacts) Stroboscopic Artefacts call on some industrial heavy weights in Perc and Paula Temple to remix Chevel’s impressive second album, while employing the PAN legend Lee Gamble too. Angus Finlayson’s Minor Science project is granted his first remix after putting out 12”s on The Trilogy Tapes and Whities, and he delivers a floating rendition of “Loop #42”, making most of the track’s instrumental grime-like tones. Perc’s remix is far more reserved - even deep you could say - than what you might expect from Ali Wells considering his more commonly associated output. Traditionally speaking, Paula Temple’s remix feels right at home on SA – but it’s Gamble's disjointed gurgle groove of “Watery Drumming” which fills us up most at Juno Plus. Fatima Yamaha - Imaginary Lines (Magnetron Music) You’ve got to hand it to Dekmantel, their reissue of underground favourite “What’s A Girl To Do” by Fatima Yamaha earlier this year has been largely responsible for the resurrection of Bas Bron’s now-loved alias. It’s easy to assume Bron’s first album as Fatima Yamaha was inspired by Dekmantel’s reissue and it comes through his own Magnetron Music, a label that’s released much of Bron’s music as Seymour Bits and Gifted in the past. Bron’s trademark synth tones shine through grubby basslines on “Borderless” while there’s oodles of ‘80s nu-boogie fun to be had on “Love Invaders”, a track that has an uncanny resemblance to Rockwell’s eerie hit “Somebody's Watching Me”. It’s not all smiles though, as there are more experimental sections too, like "Night Crossing", a track you could imagine surfacing somewhere on Clone given the chance. There’s certainly an accessible celestial quality to Fatima Yamaha’s music, and no doubt this album is just the thing many new fans of Bron’s music have been waiting for. Differ-Ent – M.O.M (Don’t Be Afraid) After he first graced Semtek’s label with his brand of energised Detroit techno back at the start of 2015, DJ Bone brings his alternative Differ-Ent project back to round off the year with a personal piece dedicated to his late mother. Having made it known this was a record that channelled the emotions he went through during a time of grieving, it certainly adds weight to the sounds Bone has wrought from his studio, not least on lead track “M.O.M”. There’s something notably painful about the straining siren tone that courses through the track, but it’s balanced out by yearning, distant tones that create the perfect juxtaposition between anger and sadness in a highly emotional but utterly powerful slice of Motor City magic. “The Final Driver” provides the chance for reflection on the flip, cooling off the raging extremes into a smooth, soothing whole. The Explosion – The Explosion (Versatile) Having previously linked up for a record entitled Terry Riley Cover EP, it’s little wonder that Versatile boss Gilb’r would be heading back into such academic territory when working with guitarist Giani Caserotto and keys man Fabrizio Rat. This new project, The Explosion, is a wide-reaching affair that certainly takes cues from pioneering composers and the legacy of kosmische amongst many other stylistic touchstones. Its variety is its charm, as the ideas flow from jammed-out 4/4 groover “Disco Blind” to the dazzling beatless swirl of 13-minute epic “Let’s Love”. “Raga 4” (almost certainly a nod to Riley and his fascination with Indian music theory) too lets rip with a long form drone bliss out, but there’s also space for more rhythmically shaped ambience as well. It’s certainly a record to be savoured end to end to achieve its full effect. Marcus Mixx – Down To New Orleans: Unreleased Tracx 1992-? (Skylax) Always trusted as one of the saucier purveyors of low down dirty Chicago house, Marcus Mixx has been enjoying renewed interest of late thanks to link ups with Unknown To The Unknown and others. Here he’s been snapped up by Skylax with a selection of tracks thematically linked thanks to the prevalence of dusty jazz samples in amongst the forthright drum machines. On “Foiled, Fooled and Fouled (Pointed Up @ Downstairs mixx)” the weapons of choice are parping trumpet refrains that sound in stark opposition to the crisp lines of the bass and the beat, but on “Wasted Funeral Tears (He Did What Mixx)” the edgy bite of the rhythm section meets more naturally with the sax squawks and spooky female choir tones. With music such as Mixx’s, a smooth combination is always secondary to the rawness of the vibe, and all three tracks here pack a punch to get crowds acting plenty naughty. DJ Qu – Social Experiment EP (Social Experiment) Having dropped heat for a variety of labels this year including his own Strength Music, DJ Qu inaugurates the Social Experiment label with an EP of uncompromising techno as direct and feisty as you’re likely to find from the man. “Final Call” is a red-blooded workout featuring bloated bass tones, a rich palette of disorientating samples and a tough jack to send shivers down the nightspot. “Odyssey” by way of contrast takes a more unhinged approach, particularly in the drum department, as a variety of heavily treated monochromatic tones collide with that alien flair that Qu has made all his own. “Track 3 (Verbal)” rounds the EP off with a savagely raw arrangement of drums and alternating synth hooks that sound stripped but tough as you could ever wish for. This is Qu in battle mode and he’s a fighter you want on your side. Pametex – PMTX005 (Frustrated Funk) Having lurked around the Hague scene since the mid-'90s, Melvin White has crept out a small but potent back catalogue of quintessentially Dutch electro. Whether he’s Dutch or not isn’t certain, but after returning from the outer reaches with the PMTX004 12” earlier in the year, another installment of stripped down machine funk is ready for digestion. The premise is a simple one to catch on to here; quite simply if you’re down with classically informed electro then you’ll love what Pametex has to offer. “Geld” brings a perfectly pitched dystopian vibe anchored by a killer bassline and eerie synth hits on top, while “DX100_Pro-One” packs a more tightly wound jam into a teasingly short run time. Somewhat flipping the script on the B-side, “Cocos” brings a warmer flavour that calls to mind Larry Heard. |

| # DJ EQUIPMENT DJ headphones DJ mixers DJ controllers DJ turntables Portable turntables CD decks PA Speakers PA Amplifiers |

0

| # STUDIO EQUIPMENT Synthesizers Drum machines Audio Interfaces Studio headphones Studio monitors Studio mixers MIDI controllers MIDI keyboards |

1

| # CASES + STORAGE Record bags Record boxes Record trolleys Vinyl storage DJ equipment hard cases DJ equipment covers Laptop stands Keyboard bags & covers |

2

| # DJ ACCESSORIES Styluses Cartridges Headshells Turntable accessories Phono preamps Handheld recorders Control vinyl Record sleeves Slipmats 45 adapters Audio cables Audio adapters Headphones parts DJ Turntable parts DJ mixer parts Hearing protection |

3